# simple state machine
#   state == 0      start, scan forward to next relevant line
#   state == 1  no longer used
#   state == 2      reached the start of the isomer analysis summary
BEGIN   { state=0; }
/^Path length distribution histogram/ {
    getline;        # Matched line
    getline;        # Discard "Unique Dynamic"
    getline;        # Discard "Length Paths Count"
        # print "Distribution: " $1, $2, $3
        unique_bylength[$1] += $2;
        dyn_bylength[$1] += $3;
    state = 0;
    next;
    }
/^\[isomer summary begin\]/ {
        getline;    # Discard "*** Isometric path ..."
        getline HDR1;  # header line 1 "Dynamic ... Dynamic..."
        getline HDR2;  # header line 2 "path unique path ..."
        getline HDR3;  # header line 3 "length paths count isomer count..."
        # print "HDR1: ", HDR1
        # print "HDR2: ", HDR2
        # print "HDR3: ", HDR3
        state=2;
        next;
    }
/^\[isomer summary end\]/ {
        state=0;
    }

    { if (state == 2) {
        # print "LINE: ", $1, $2, $3, $4, $5
        if (maxlen < $1)    { maxlen = $1; }
        unique_bylength[$1] += $2;
        dyn_bylength[$1] += $3;
        allisomers_bylength[$1] += $4;
        dynallisomers[$1] += $5;
        rotational_bylength[$1] += $6;
        dynrotational[$1] += $7;
        palindromic_bylength[$1] += $8;
        dynpalindromic[$1] += $9;

        total_uniques += $2;
        total_dynuniques += $3;
        total_isomers += $4;
        total_dynisomers += $5;
        total_rotationals += $6;
        total_dynrotationals += $7;
        total_palindromes += $8;
        total_dynpalindromes += $9;
        }
    }

END     {
            print "Net Isometric Paths summary:";
            print HDR1;
            print HDR2;
            print HDR3;
            # print "MAXLEN: " maxlen
            for (i = 1; i <= maxlen; i++)
            {
                if (unique_bylength[i] == 0) unique_bylength[i] = 0;
                if (dyn_bylength[i] == 0) dyn_bylength[i] = 0;
                if (allisomers_bylength[i] == 0) allisomers_bylength[i] = 0;
                if (dynallisomers[i] == 0) dynallisomers[i] = 0;
                if (rotational_bylength[i] == 0) rotational_bylength[i] = 0;
                if (dynrotational[i] == 0) dynrotational[i] = 0;
                if (palindromic_bylength[i] == 0) palindromic_bylength[i] = 0;
                if (dynpalindromic[i] == 0) dynpalindromic[i] = 0;

                print i "\t" \
                        unique_bylength[i] "\t" dyn_bylength[i] "\t\t" \
                        allisomers_bylength[i] "\t" dynallisomers[i] "\t\t" \
                        rotational_bylength[i] "\t" dynrotational[i] "\t\t" \
                        palindromic_bylength[i] "\t" dynpalindromic[i];

            }
            print "Net:\t" total_uniques "\t" total_dynuniques "\t\t" \
                        total_isomers "\t" total_dynisomers "\t\t" \
                        total_rotationals "\t" total_dynrotationals \
                        "\t\t" total_palindromes "\t" total_dynpalindromes;
        }
